/***************************************************************************
                          icecc.cpp  -  description
                             -------------------
    begin                :   14 21:00:28 EEST 2002
    copyright            : (C) 2002 by Vadim A. Khohlov
    email                : xvadim@teko.kherson.ua
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>

#include <qaccel.h>
#include <qmessagebox.h>

#include <qdir.h>
#include <qfile.h>
#include <qtextstream.h>
#include <qpixmap.h>

#include "icecc.h"
#include "qcentralwidget.h"
#include "qtoolcfg.h"
#include "tools.h"
#include "iconmenu.xpm"
#include "iconprefs.xpm"
#include "iconwinprops.xpm"
#include "icontoolbar.xpm"
#include "iconkeys.xpm"
#include "iconsndcfg.xpm"
#include "icontheme.xpm"
#include "iconbackground.xpm"
#include "iconexit.xpm"
#include "iconcursors.xpm"
#include "iconiconcvt.xpm"

IceCCApp::IceCCApp():
toolCfg(0),
icewmCfgDir(getenv("ICEWM_PRIVCFG"))
{
    setCaption(tr("IceWM Control Center " VERSION));

    initMenuBar();
    initStatusBar();

    QCentralWidget *cWidget = new QCentralWidget(this);
    setCentralWidget(cWidget);

    setMaximumSize(cWidget->width(),
                   cWidget->height() + menuBar()->height() + statusBar()->height());

    if(icewmCfgDir.isNull())
        icewmCfgDir = QDir::homeDirPath() + "/.icewm";

    loadOptions();
}//constructor

IceCCApp::~IceCCApp()
{
}//destructor


const char *toolAccel[] = {"Ctrl+M", "Ctrl+P", "Ctrl+W", "Ctrl+T",
                           "Ctrl+K", "Ctrl+S", "Ctrl+H", "Ctrl+B",
			   "Ctrl+I", "Ctrl+U"};


void IceCCApp::initMenuBar()
{

  toolMenu = new QPopupMenu(this);
//  for(int i = 0; i < COUNTTOOLS; i++)
//    toolMenu->insertItem(toolNames[i], this, SLOT(runTool(int)),
//                         QAccel::stringToKey(toolAccel[i]), i);
  toolMenu->insertItem(QPixmap(iconmenu_xpm), toolNames[0], this, 
	  SLOT(runTool(int)), QAccel::stringToKey(toolAccel[0]), 0);
  toolMenu->insertItem(QPixmap(iconprefs_xpm), toolNames[1], this, 
	  SLOT(runTool(int)), QAccel::stringToKey(toolAccel[1]), 1);
  toolMenu->insertItem(QPixmap(iconwinprops_xpm), toolNames[2], this, 
	  SLOT(runTool(int)), QAccel::stringToKey(toolAccel[2]), 2);
  toolMenu->insertItem(QPixmap(icontoolbar_xpm), toolNames[3], this, 
	  SLOT(runTool(int)), QAccel::stringToKey(toolAccel[3]), 3);
  toolMenu->insertItem(QPixmap(iconkeys_xpm), toolNames[4], this, 
	  SLOT(runTool(int)), QAccel::stringToKey(toolAccel[4]), 4);
  toolMenu->insertItem(QPixmap(iconsndcfg_xpm), toolNames[5], this, 
	  SLOT(runTool(int)), QAccel::stringToKey(toolAccel[5]), 5);
  toolMenu->insertItem(QPixmap(icontheme_xpm), toolNames[6], this, 
	  SLOT(runTool(int)), QAccel::stringToKey(toolAccel[6]), 6);
  toolMenu->insertItem(QPixmap(iconbackground_xpm), toolNames[7], this, 
	  SLOT(runTool(int)), QAccel::stringToKey(toolAccel[7]), 7);
  toolMenu->insertItem(QPixmap(iconcursors_xpm), toolNames[8], this,
	  SLOT(runTool(int)), QAccel::stringToKey(toolAccel[8]), 8);
  toolMenu->insertItem(QPixmap(iconiconcvt_xpm), toolNames[9], this,
	  SLOT(runTool(int)), QAccel::stringToKey(toolAccel[9]), 9);


  toolMenu->insertSeparator();
  toolMenu->insertItem("&Options...", this, SLOT(slotToolOptions()), 
		  CTRL+Key_O);

  toolMenu->insertSeparator();
  toolMenu->insertItem(QPixmap(iconexit_xpm),"&Quit", qApp, SLOT(quit())
		  , CTRL+Key_Q);


  helpMenu=new QPopupMenu();
  helpMenu->insertItem("&About", this, SLOT(slotHelpAbout()));

  menuBar()->insertItem(tr("&Tools"), toolMenu);
  menuBar()->insertSeparator();
  menuBar()->insertItem(tr("&Help"), helpMenu);
}/* initMenuBar() */

void IceCCApp::initStatusBar()
{
  statusBar()->message(tr("Ready."), 2000);
}

/////////////////////////////////////////////////////////////////////
// SLOT IMPLEMENTATION
/////////////////////////////////////////////////////////////////////

void IceCCApp::slotHelpAbout()
{
  QMessageBox::about(this,tr("About..."),
    tr("IceWM Control Center\nVersion " VERSION "\n(c) 2002-2003 by Vadim A. Khohlov"));
}

/** No descriptions */
void IceCCApp::slotToolOptions()
{
    if(!toolCfg)
    {
        toolCfg = new QToolCfg(this);
        CHECK_PTR(toolCfg);
    }
    toolCfg->setTools(toolsCmd);
    if( toolCfg->exec() == QDialog::Accepted)
        saveOptions();
}/* IceCCApp::slotToolOptions() */

/**
 * Runs a tool with number numTool.
 */
void IceCCApp::runTool(int numTool)
{
    QString cmd(toolsCmd[numTool]);
    cmd += '&';
    system(cmd.data());
}/* IceCCApp::runTools(int numTool) */
/** 
 * Loads a command lines for tools.
 */
void IceCCApp::loadOptions()
{
    int numTool = 0;
    QString s;
    QString optFileName(icewmCfgDir);
    optFileName += "/.icecc";

    QFile optFile(optFileName);
    if(optFile.open(IO_ReadOnly))
    {
        QTextStream optStream(&optFile);
        while((s = optStream.readLine()) != QString::null)
        {
			if(s[0] != '#') /* skip comments*/
			{
            	toolsCmd[numTool] = s.stripWhiteSpace();
				if(!toolsCmd[numTool].isEmpty())	/* skip empty line */
					numTool++;
			}
        } /* for */
    }/* if(optFile.open(IO_ReadOnly)) */
    else /* Load default options */
    {
        QMessageBox::warning(this, tr("Attention!"),
         tr("Cann't read file .icecc into IceWM's directory.\n"
	    " The default tools will be used.\n"
            "See Options menu for details..."));
        for(numTool = 0; numTool < COUNTTOOLS; numTool++)
            toolsCmd[numTool] = tools[numTool];
    }/* else if(optFile.open(IO_ReadOnly)) */
}/* IceCCApp::loadOptions() */

/** No descriptions */
void IceCCApp::setTools(QString tools[COUNTTOOLS])
{
    for(int i = 0; i < COUNTTOOLS; i++)
        toolsCmd[i] = tools[i];
}/* IceCCApp::setTools(QString tools[COUNTTOOLS]) */

/** No descriptions */
void IceCCApp::saveOptions()
{
    QString optFileName(icewmCfgDir);
    optFileName += "/.icecc";

    QFile optFile(optFileName);
    if(optFile.open(IO_WriteOnly))
    {
        QTextStream optStream(&optFile);
		optStream << tr("# This file contains the list of tools for IceWM Control Center.\n"
				"# !!IMPORTANT!! This tools must be listed in such order:\n"
				"# 1. Menu editor\n"
				"# 2. Preferences editor\n"
				"# 3. Winoptions editor\n"
				"# 4. Toolbar editor\n"
				"# 5. Keys editor\n"
				"# 6. Sound configurator\n"
				"# 7. Themes' switcher\n"
				"# 8. Background options editor.\n"
    		                "# 9. Cursors configurator\n"
				"# 10. Icons' convertor\n\n");
        for(int i = 0; i < COUNTTOOLS; i++)
            optStream << toolsCmd[i] << '\n';
    }/* if(optFile.open(IO_WriteOnly)) */
}/* IceCCApp::saveOptions() */
